import json
from file_tools.utils.functions import get_file

#: Import JSON

def import_json(file, relative=False):
	file = get_file(file) if not relative else get_file(f'{get_caller_path()}/{file}', relative)
	with open(file, 'r') as f:
		try:
			return json.load(f)
		except:
			return {}

#: Export JSON

def export_json(data, file, indent=2, relative=False):
	file = get_file(file) if not relative else get_file(f'{get_caller_path()}/{file}', relative)
	with open(file, 'w') as f:
		json.dump(data, f, indent=indent)

#::: END PROGRAM :::



import os
import inspect

#: Get Filename with Context

def get_file(file, relative=False):
	if not relative:
		return f'{os.getcwd()}/{file}'
	else:
		return file

#: Get Path of Caller

def get_caller_path():
	for item in inspect.stack():
		if item and __file__ not in item and item.function == '<module>' and item.index == 0:
			return os.path.dirname(os.path.abspath(item.filename))

#::: END PROGRAM :::



import setuptools

with open("README.md", "r") as fh:
	long_description = fh.read()

setuptools.setup(
	name="file-tools",
	version="0.1.1",
	author="Edmund Pfeil",
	author_email="edmundpf@buffalo.edu",
	description="File and JSON File Methods.",
	long_description=long_description,
	long_description_content_type="text/markdown",
	url="https://github.com/edmundpf/print_tools",
	install_requires=['colorful'],
	packages=setuptools.find_packages(),
	classifiers=[
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
	],
)



from file_tools.utils.functions import get_file, get_caller_path

#: Get File String

def get_file_string(file, relative=False):
	file = get_file(file) if not relative else get_file(f'{get_caller_path()}/{file}', relative)
	with open(file, 'r') as f:
		return f.read()

#: Get File Lines

def get_file_lines(file, newline='\n', relative=False):
	file = get_file(file) if not relative else get_file(f'{get_caller_path()}/{file}', relative)
	with open(file, 'r') as f:
		return [l.rstrip(newline) for l in f]

#::: END PROGRAM :::
